referrerpolicy=no-referrer-when-downgrade

WeightInfo

Trait WeightInfo 

pub trait WeightInfo {
    // Required methods
    fn enter_empty() -> Weight;
    fn enter_variable_disputes(v: u32) -> Weight;
    fn enter_bitfields() -> Weight;
    fn enter_backed_candidates_variable(v: u32) -> Weight;
    fn enter_backed_candidate_code_upgrade() -> Weight;
}

Required Methods

fn enter_empty() -> Weight

The weight of processing an empty parachain inherent.

fn enter_variable_disputes(v: u32) -> Weight

Variant over v, the count of dispute statements in a dispute statement set. This gives the weight of a single dispute statement set.

fn enter_bitfields() -> Weight

The weight of one bitfield.

fn enter_backed_candidates_variable(v: u32) -> Weight

Variant over v, the count of validity votes for a backed candidate. This gives the weight of a single backed candidate.

fn enter_backed_candidate_code_upgrade() -> Weight

The weight of a single backed candidate with a code upgrade.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl WeightInfo for TestWeightInfo

Available on crate feature runtime-benchmarks only.